File: fix-typo

package info (click to toggle)
ballerburg 1.2.0-4
  • links: PTS, VCS
  • area: main
  • in suites: bullseye
  • size: 616 kB
  • sloc: ansic: 5,942; sh: 65; makefile: 10
file content (58 lines) | stat: -rw-r--r-- 2,528 bytes parent folder | download | duplicates (2)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
Description: <short summary of the patch>
 TODO: Put a short summary on the line above and replace this paragraph
 with a longer explanation of this change. Complete the meta-information
 with other relevant fields (see below for details). To make it easier, the
 information below has been extracted from the changelog. Adjust it or drop
 it.
 .
 ballerburg (1.2.0-3) unstable; urgency=medium
 .
   * debian/menu: dropped, install debian/ballerburg.desktop instead.
   * debian/rules: Drop autotools call.
   * Bump standards version to 4.2.1.
Author: Gürkan Myczko <gurkan@phys.ethz.ch>

---
The information above should follow the Patch Tagging Guidelines, please
checkout http://dep.debian.net/deps/dep3/ to learn about the format. Here
are templates for supplementary fields that you might want to add:

Origin: <vendor|upstream|other>, <url of original patch>
Bug: <url in upstream bugtracker>
Bug-Debian: https://bugs.debian.org/<bugnumber>
Bug-Ubuntu: https://launchpad.net/bugs/<bugnumber>
Forwarded: <no|not-needed|url proving that it has been forwarded>
Reviewed-By: <name and email of someone who approved the patch>
Last-Update: 2018-09-12

--- ballerburg-1.2.0.orig/doc/en/manual.html
+++ ballerburg-1.2.0/doc/en/manual.html
@@ -186,7 +186,7 @@ The second part of the dialog is used fo
 things and repair your castle. You can trigger one of the actions by clicking
 on the price of the corresponding entry.
 However, this is only possible if the entry is active. In case it is inactive,
-you either do not have enough money or one of the following reasons occured:
+you either do not have enough money or one of the following reasons occurred:
 </p>
 <ul>
  <li>You can have only one vane. If you already have one, the entry for a new
--- ballerburg-1.2.0.orig/src/sdlgui.c
+++ ballerburg-1.2.0/src/sdlgui.c
@@ -191,7 +191,7 @@ int SDLGui_SetScreen(SDL_Surface *pScrn)
 
 	if (pFontGfx == NULL)
 	{
-		fprintf(stderr, "Error: A problem with the font occured!\n");
+		fprintf(stderr, "Error: A problem with the font occurred!\n");
 		return -1;
 	}
 
@@ -805,7 +805,7 @@ static int SDLGui_SearchFlaggedButton(co
 /*-----------------------------------------------------------------------*/
 /**
  * Show and process a dialog. Returns the button number that has been
  * pressed or SDLGUI_UNKNOWNEVENT if an unsupported event occured (will be
  * stored in parameter pEventOut).
  */
 int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
@@ -805,7 +805,7 @@ static int SDLGui_SearchFlaggedButton(co
 /**
  * Show and process a dialog. Returns the button number that has been
- * pressed or SDLGUI_UNKNOWNEVENT if an unsupported event occured (will be
+ * pressed or SDLGUI_UNKNOWNEVENT if an unsupported event occurred (will be
  * stored in parameter pEventOut).
  */